@@ -145,19 +145,19 @@ Decoration::~Decoration()
 {
     // Deleted by label directly.
 #if 0
-    for (Element::List lst : qAsConst(mDayElements)) {
+    for (Element::List lst : std::as_const(mDayElements)) {
         qDeleteAll(lst);
         lst.clear();
     }
-    for (Element::List lst : qAsConst(mWeekElements)) {
+    for (Element::List lst : std::as_const(mWeekElements)) {
         qDeleteAll(lst);
         lst.clear();
     }
-    for (Element::List lst : qAsConst(mMonthElements)) {
+    for (Element::List lst : std::as_const(mMonthElements)) {
         qDeleteAll(lst);
         lst.clear();
     }
-    for (Element::List lst : qAsConst(mYearElements)) {
+    for (Element::List lst : std::as_const(mYearElements)) {
         qDeleteAll(lst);
         lst.clear();
     }
@@ -259,18 +259,18 @@ Element::List Decoration::createYearElements(const QDate &)
     return Element::List();
 }
 
-QDate Decoration::weekDate(const QDate &date)
+QDate Decoration::weekDate(QDate date)
 {
     QDate result = date;
     return result.addDays(date.dayOfWeek() - 1);
 }
 
-QDate Decoration::monthDate(const QDate &date)
+QDate Decoration::monthDate(QDate date)
 {
     return {date.year(), date.month(), 1};
 }
 
-QDate Decoration::yearDate(const QDate &date)
+QDate Decoration::yearDate(QDate date)
 {
     return {date.year(), 1, 1};
 }
