@@ -42,7 +42,7 @@ JournalDateView::~JournalDateView()
 {
 }
 
-void JournalDateView::setDate(const QDate &date)
+void JournalDateView::setDate(QDate date)
 {
     mDate = date;
     Q_EMIT setDateSignal(date);
@@ -90,7 +90,7 @@ Akonadi::Item::List JournalDateView::journals() const
 {
     Akonadi::Item::List l;
     l.reserve(mEntries.count());
-    for (const JournalFrame *const i : qAsConst(mEntries)) {
+    for (const JournalFrame *const i : std::as_const(mEntries)) {
         l.push_back(i->journal());
     }
     return l;
@@ -241,7 +241,7 @@ void JournalFrame::setCalendar(const Akonadi::ETMCalendar::Ptr &calendar)
     mCalendar = calendar;
 }
 
-void JournalFrame::setDate(const QDate &date)
+void JournalFrame::setDate(QDate date)
 {
     mDate = date;
 }
