@@ -34,14 +34,16 @@ public:
     QWidget *parentWidget() const;
 
     /**
-      Compares two events
+      Compares two items to decide which to place in the view first.
 
       The month view displays a list of items. When loading (which occurs each
-      time there is a change), the items are sorted :
-      - smallest date
-      - bigger span
-      - floating
+      time there is a change), the items are sorted in an order intended to
+      avoid unsightly gaps:
+      - biggest durations first
+      - earliest date
       - finally, time in the day
+      Holidays are sorted before events with the same start date and length,
+      so they appear at the top of the day's box.
     */
     static bool greaterThan(const MonthItem *e1, const MonthItem *e2);
 
@@ -334,18 +336,19 @@ class EVENTVIEWS_EXPORT HolidayMonthItem : public MonthItem
 
 public:
     HolidayMonthItem(MonthScene *monthScene, QDate date, const QString &name);
+    HolidayMonthItem(MonthScene *monthScene, QDate startDate, QDate endDate, const QString &name);
     ~HolidayMonthItem() override;
 
     bool greaterThanFallback(const MonthItem *other) const override;
 
     QDate realStartDate() const override
     {
-        return mDate;
+        return mStartDate;
     }
 
     QDate realEndDate() const override
     {
-        return mDate;
+        return mEndDate;
     }
 
     bool allDay() const override
@@ -384,7 +387,8 @@ protected:
     void finalizeResize(const QDate &newStartDate, const QDate &newEndDate) override;
 
 private:
-    QDate mDate;
+    QDate mStartDate;
+    QDate mEndDate;
     QString mName;
 };
 }
