@@ -5,8 +5,7 @@
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef CALENDARVIEWS_TODOMODEL_P_H
-#define CALENDARVIEWS_TODOMODEL_P_H
+#pragma once
 
 #include "todomodel.h"
 
@@ -60,4 +59,3 @@ private:
     TodoModel *const q;
 };
 
-#endif
