@@ -33,6 +33,7 @@
 
 #include <KCalendarCore/CalFormat>
 
+#include <KConfig>
 #include <KJob>
 
 #include <QGridLayout>
@@ -81,7 +82,7 @@ public:
     {
         const QString todoMimeType = QStringLiteral("application/x-vnd.akonadi.calendar.todo");
         if (flat) {
-            for (TodoView *view : qAsConst(views)) {
+            for (TodoView *view : std::as_const(views)) {
                 // In flatview dropping confuses users and it's very easy to drop into a child item
                 view->mView->setDragDropMode(QAbstractItemView::DragOnly);
                 view->setFlatView(flat, /**propagate=*/false); // So other views update their toggle icon
@@ -102,7 +103,7 @@ public:
         } else {
             delete todoTreeModel;
             todoTreeModel = new IncidenceTreeModel(QStringList() << todoMimeType, parent);
-            for (TodoView *view : qAsConst(views)) {
+            for (TodoView *view : std::as_const(views)) {
                 QObject::connect(todoTreeModel, &IncidenceTreeModel::indexChangedParent, view, &TodoView::expandIndex);
                 QObject::connect(todoTreeModel, &IncidenceTreeModel::batchInsertionFinished, view, &TodoView::restoreViewState);
                 view->mView->setDragDropMode(QAbstractItemView::DragDrop);
@@ -114,7 +115,7 @@ public:
             todoFlatModel = nullptr;
         }
 
-        for (TodoView *view : qAsConst(views)) {
+        for (TodoView *view : std::as_const(views)) {
             view->mFlatViewButton->blockSignals(true);
             // We block signals to avoid recursion, we have two TodoViews and mFlatViewButton is synchronized
             view->mFlatViewButton->setChecked(flat);
@@ -642,7 +643,7 @@ void TodoView::addQuickTodo(Qt::KeyboardModifiers modifiers)
         }
         const QModelIndex idx = mProxyModel->mapToSource(selection[0]);
         mView->expand(selection[0]);
-        const Akonadi::Item parent = sModels->todoModel->data(idx, Akonadi::EntityTreeModel::ItemRole).value<Akonadi::Item>();
+        const auto parent = sModels->todoModel->data(idx, Akonadi::EntityTreeModel::ItemRole).value<Akonadi::Item>();
         addTodo(mQuickAdd->text(), parent, mProxyModel->categories());
     } else {
         return;
@@ -650,12 +651,12 @@ void TodoView::addQuickTodo(Qt::KeyboardModifiers modifiers)
     mQuickAdd->setText(QString());
 }
 
-void TodoView::contextMenu(const QPoint &pos)
+void TodoView::contextMenu(QPoint pos)
 {
     const bool hasItem = mView->indexAt(pos).isValid();
     Incidence::Ptr incidencePtr;
 
-    for (QAction *entry : qAsConst(mItemPopupMenuItemOnlyEntries)) {
+    for (QAction *entry : std::as_const(mItemPopupMenuItemOnlyEntries)) {
         bool enable;
 
         if (hasItem) {
@@ -724,7 +725,7 @@ void TodoView::selectionChanged(const QItemSelection &selected, const QItemSelec
         return;
     }
 
-    const Akonadi::Item todoItem = selection[0].data(TodoModel::TodoRole).value<Akonadi::Item>();
+    const auto todoItem = selection[0].data(TodoModel::TodoRole).value<Akonadi::Item>();
 
     if (selectedIncidenceDates().isEmpty()) {
         Q_EMIT incidenceSelected(todoItem, QDate());
@@ -740,7 +741,7 @@ void TodoView::showTodo()
         return;
     }
 
-    const Akonadi::Item todoItem = selection[0].data(TodoModel::TodoRole).value<Akonadi::Item>();
+    const auto todoItem = selection[0].data(TodoModel::TodoRole).value<Akonadi::Item>();
 
     Q_EMIT showIncidenceSignal(todoItem);
 }
@@ -752,7 +753,7 @@ void TodoView::editTodo()
         return;
     }
 
-    const Akonadi::Item todoItem = selection[0].data(TodoModel::TodoRole).value<Akonadi::Item>();
+    const auto todoItem = selection[0].data(TodoModel::TodoRole).value<Akonadi::Item>();
     Q_EMIT editIncidenceSignal(todoItem);
 }
 
@@ -760,7 +761,7 @@ void TodoView::deleteTodo()
 {
     QModelIndexList selection = mView->selectionModel()->selectedRows();
     if (selection.size() == 1) {
-        const Akonadi::Item todoItem = selection[0].data(TodoModel::TodoRole).value<Akonadi::Item>();
+        const auto todoItem = selection[0].data(TodoModel::TodoRole).value<Akonadi::Item>();
 
         if (!changer()->deletedRecently(todoItem.id())) {
             Q_EMIT deleteIncidenceSignal(todoItem);
@@ -777,7 +778,7 @@ void TodoView::newSubTodo()
 {
     QModelIndexList selection = mView->selectionModel()->selectedRows();
     if (selection.size() == 1) {
-        const Akonadi::Item todoItem = selection[0].data(TodoModel::TodoRole).value<Akonadi::Item>();
+        const auto todoItem = selection[0].data(TodoModel::TodoRole).value<Akonadi::Item>();
 
         Q_EMIT newSubTodoSignal(todoItem);
     } else {
@@ -786,7 +787,7 @@ void TodoView::newSubTodo()
     }
 }
 
-void TodoView::copyTodoToDate(const QDate &date)
+void TodoView::copyTodoToDate(QDate date)
 {
     if (!changer()) {
         return;
@@ -800,7 +801,7 @@ void TodoView::copyTodoToDate(const QDate &date)
     const QModelIndex origIndex = mProxyModel->mapToSource(selection[0]);
     Q_ASSERT(origIndex.isValid());
 
-    const Akonadi::Item origItem = sModels->todoModel->data(origIndex, Akonadi::EntityTreeModel::ItemRole).value<Akonadi::Item>();
+    const auto origItem = sModels->todoModel->data(origIndex, Akonadi::EntityTreeModel::ItemRole).value<Akonadi::Item>();
 
     const KCalendarCore::Todo::Ptr orig = CalendarSupport::todo(origItem);
     if (!orig) {
@@ -845,7 +846,7 @@ QMenu *TodoView::createCategoryPopupMenu()
         return tempMenu;
     }
 
-    const Akonadi::Item todoItem = selection[0].data(TodoModel::TodoRole).value<Akonadi::Item>();
+    const auto todoItem = selection[0].data(TodoModel::TodoRole).value<Akonadi::Item>();
     KCalendarCore::Todo::Ptr todo = CalendarSupport::todo(todoItem);
     Q_ASSERT(todo);
 
@@ -869,7 +870,7 @@ void TodoView::onTagsFetched(KJob *job)
     }
     auto fetchJob = static_cast<Akonadi::TagFetchJob *>(job);
     const QStringList checkedCategories = job->property("checkedCategories").toStringList();
-    QPointer<QMenu> menu = job->property("menu").value<QPointer<QMenu>>();
+    auto menu = job->property("menu").value<QPointer<QMenu>>();
     if (menu) {
         const auto lst = fetchJob->tags();
         for (const Akonadi::Tag &tag : lst) {
@@ -884,24 +885,20 @@ void TodoView::onTagsFetched(KJob *job)
     }
 }
 
-void TodoView::setNewDate(const QDate &date)
+void TodoView::setNewDate(QDate date)
 {
     QModelIndexList selection = mView->selectionModel()->selectedRows();
     if (selection.size() != 1) {
         return;
     }
 
-    const Akonadi::Item todoItem = selection[0].data(TodoModel::TodoRole).value<Akonadi::Item>();
+    const auto todoItem = selection[0].data(TodoModel::TodoRole).value<Akonadi::Item>();
     KCalendarCore::Todo::Ptr todo = CalendarSupport::todo(todoItem);
     Q_ASSERT(todo);
 
     if (calendar()->hasRight(todoItem, Akonadi::Collection::CanChangeItem)) {
         KCalendarCore::Todo::Ptr oldTodo(todo->clone());
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-        QDateTime dt(date);
-#else
         QDateTime dt(date.startOfDay());
-#endif
 
         if (!todo->allDay()) {
             dt.setTime(todo->dtDue().time());
@@ -922,7 +919,7 @@ void TodoView::setNewPercentage(QAction *action)
         return;
     }
 
-    const Akonadi::Item todoItem = selection[0].data(TodoModel::TodoRole).value<Akonadi::Item>();
+    const auto todoItem = selection[0].data(TodoModel::TodoRole).value<Akonadi::Item>();
     KCalendarCore::Todo::Ptr todo = CalendarSupport::todo(todoItem);
     Q_ASSERT(todo);
 
@@ -952,7 +949,7 @@ void TodoView::setNewPriority(QAction *action)
     if (selection.size() != 1) {
         return;
     }
-    const Akonadi::Item todoItem = selection[0].data(TodoModel::TodoRole).value<Akonadi::Item>();
+    const auto todoItem = selection[0].data(TodoModel::TodoRole).value<Akonadi::Item>();
     KCalendarCore::Todo::Ptr todo = CalendarSupport::todo(todoItem);
     if (calendar()->hasRight(todoItem, Akonadi::Collection::CanChangeItem)) {
         KCalendarCore::Todo::Ptr oldTodo(todo->clone());
@@ -969,7 +966,7 @@ void TodoView::changedCategories(QAction *action)
         return;
     }
 
-    const Akonadi::Item todoItem = selection[0].data(TodoModel::TodoRole).value<Akonadi::Item>();
+    const auto todoItem = selection[0].data(TodoModel::TodoRole).value<Akonadi::Item>();
     KCalendarCore::Todo::Ptr todo = CalendarSupport::todo(todoItem);
     Q_ASSERT(todo);
     if (calendar()->hasRight(todoItem, Akonadi::Collection::CanChangeItem)) {
@@ -1042,7 +1039,7 @@ void TodoView::onRowsInserted(const QModelIndex &parent, int start, int end)
         return;
     }
 
-    Akonadi::Item item = v.value<Akonadi::Item>();
+    auto item = v.value<Akonadi::Item>();
     if (!item.isValid()) {
         return;
     }
@@ -1190,7 +1187,7 @@ void TodoView::createEvent()
         return;
     }
 
-    const Akonadi::Item todoItem = selection[0].data(TodoModel::TodoRole).value<Akonadi::Item>();
+    const auto todoItem = selection[0].data(TodoModel::TodoRole).value<Akonadi::Item>();
 
     Q_EMIT createEvent(todoItem);
 }
@@ -1202,7 +1199,7 @@ void TodoView::createNote()
         return;
     }
 
-    const Akonadi::Item todoItem = selection[0].data(TodoModel::TodoRole).value<Akonadi::Item>();
+    const auto todoItem = selection[0].data(TodoModel::TodoRole).value<Akonadi::Item>();
 
     Q_EMIT createNote(todoItem);
 }
